==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-monitor/lxqt-config-monitor_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../../../fastmenu.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Hızlı Seçenekler</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Genişletilmiş görünüm</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Birleştirilmiş görünüm</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Yalnız birinci</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Yalnız ikinci</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitör Ayarları</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Kaydedilmiş Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation>Ters Çevrilmiş</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation>Doğru</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation>Yanlış</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>Adı:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../../../monitorpicture.ui" line="14"/>
        <source>Dialog</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Eklenmiş monitörleri sakla</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitör Ayarları</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>Hızlı Menü</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>Konumu ayarla</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation>Gelişmiş ayarlar</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Ayarla</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Çözünürlük:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Bu ekranı etkinleştir</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Bu benim birinci ekranım</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Bu ekran genişletilmiş diğer ekran</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Yineleme oranı:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Yönlendir:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Bilgi göster</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>Adı: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>Üretici: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>Serisi: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Ekran boyutu: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>Seri numarası: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA cihaz ID: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="159"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="160"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Inverted</source>
        <translation>Ters Çevrilmiş</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="252"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Kaydedilmiş Ayarları Yönet</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Ayarlar değiştirildi</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Mevcut ayarlar uygun mu?</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%1 second(s) remaining</source>
        <translation>%1 saniye kaldı</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-config/lxqt-config-monitor/lxqt-config-monitor_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>FastMenu</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Form</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Hızlı Seçenekler</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Genişletilmiş görünüm</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Birleştirilmiş görünüm</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Yalnız birinci</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Yalnız ikinci</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitör Ayarları</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Kaydedilmiş Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation>Ters Çevrilmiş</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation>Doğru</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation>Yanlış</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>Adı:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Pencere</translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Eklenmiş monitörleri sakla</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitör Ayarları</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>Hızlı Menü</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>Konumu ayarla</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation>Gelişmiş ayarlar</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Ayarla</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Çözünürlük:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Bu ekranı etkinleştir</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Bu benim birinci ekranım</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Bu ekran genişletilmiş diğer ekran</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Yineleme oranı:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Yönlendir:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Bilgi göster</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>Adı: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>Üretici: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>Serisi: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Ekran boyutu: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>Seri numarası: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA cihaz ID: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation>Ters Çevrilmiş</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="254"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Kaydedilmiş Ayarları Yönet</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Ayarlar değiştirildi</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Mevcut ayarlar uygun mu?</translation>
    </message>
    <message>
        <source>%1 second(s) remaining</source>
        <translation type="vanished">%1 saniye kaldı</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%n second(s) remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
</TS>
